const expect = require('chai').expect;

const varsnap = require('../varsnap/core');

const origConfigs = {};
class ConfigTools {
  static writeConfig(k, v) {
    if (typeof window === 'undefined') {
      process.env[k] = v;
      return;
    }
    if (!window[varsnap.browserConfig]) {
      window[varsnap.browserConfig] = {};
    }
    window[varsnap.browserConfig][k] = v;
  }

  static saveConfigs() {
    for (let k in varsnap.configKeys) {
      origConfigs[k] = varsnap.Util.getConfig(varsnap.configKeys[k]);
    }
  }

  static restoreConfigs() {
    for (let k in varsnap.configKeys) {
      ConfigTools.writeConfig(varsnap.configKeys[k], origConfigs[k]);
    }
  }
}

describe('ConfigTools', () => {
  context('node', () => {
    before(function() {
      if (typeof window !== 'undefined') {
        this.skip();
      }
    });
    it('can save and restore configs', () => {
      ConfigTools.writeConfig(varsnap.configKeys.env, 'asdf');
      expect(process.env[varsnap.configKeys.env]).to.equal('asdf');
      expect(varsnap.Util.getConfig(varsnap.configKeys.env)).to.equal('asdf');
      ConfigTools.saveConfigs();
      expect(varsnap.Util.getConfig(varsnap.configKeys.env)).to.equal('asdf');
      ConfigTools.writeConfig(varsnap.configKeys.env, 'qwer');
      expect(varsnap.Util.getConfig(varsnap.configKeys.env)).to.equal('qwer');
      ConfigTools.restoreConfigs();
      expect(varsnap.Util.getConfig(varsnap.configKeys.env)).to.equal('asdf');
      ConfigTools.writeConfig(varsnap.configKeys.env, '');
    });
  });
  context('browser', () => {
    before(function() {
      if (typeof window === 'undefined') {
        this.skip();
      }
    });
    it('can save and restore configs', () => {
      ConfigTools.writeConfig(varsnap.configKeys.env, 'asdf');
      expect(window[varsnap.browserConfig][varsnap.configKeys.env]).to.equal('asdf');
      expect(varsnap.Util.getConfig(varsnap.configKeys.env)).to.equal('asdf');
      ConfigTools.saveConfigs();
      expect(varsnap.Util.getConfig(varsnap.configKeys.env)).to.equal('asdf');
      ConfigTools.writeConfig(varsnap.configKeys.env, 'qwer');
      expect(varsnap.Util.getConfig(varsnap.configKeys.env)).to.equal('qwer');
      ConfigTools.restoreConfigs();
      expect(varsnap.Util.getConfig(varsnap.configKeys.env)).to.equal('asdf');
      ConfigTools.writeConfig(varsnap.configKeys.env, '');
    });
  });
});

module.exports = ConfigTools;
